@@ -3,11 +3,11 @@
 
 use std::process::{Command, Stdio};
 
-use lazy_static::*;
+use once_cell::sync::Lazy;
 use std::sync::{Arc, Mutex};
 
-use colored::*;
 use eyre::{eyre, WrapErr};
+use owo_colors::OwoColorize;
 use pgx::*;
 use pgx_utils::pg_config::{PgConfig, Pgx};
 use pgx_utils::{createdb, get_named_capture, get_target_dir};
@@ -25,14 +25,15 @@ struct SetupState {
     system_session_id: String,
 }
 
-lazy_static! {
-    static ref TEST_MUTEX: Mutex<SetupState> = Mutex::new(SetupState {
+static TEST_MUTEX: Lazy<Mutex<SetupState>> = Lazy::new(|| {
+    Mutex::new(SetupState {
         installed: false,
         loglines: Arc::new(Mutex::new(HashMap::new())),
         system_session_id: "NONE".to_string(),
-    });
-    static ref SHUTDOWN_HOOKS: Mutex<Vec<Box<dyn Fn() + Send>>> = Mutex::new(Vec::new());
-}
+    })
+});
+static SHUTDOWN_HOOKS: Lazy<Mutex<Vec<Box<dyn Fn() + Send>>>> =
+    Lazy::new(|| Mutex::new(Vec::new()));
 
 fn register_shutdown_hook() {
     extern "C" fn run_shutdown_hooks() {
@@ -239,7 +240,8 @@ fn install_extension() -> eyre::Result<()> {
     if !features.contains("pg_test") {
         features += " pg_test";
     }
-    let no_default_features = std::env::var("PGX_NO_DEFAULT_FEATURES").unwrap_or("false".to_string()) == "true";
+    let no_default_features =
+        std::env::var("PGX_NO_DEFAULT_FEATURES").unwrap_or("false".to_string()) == "true";
     let all_features = std::env::var("PGX_ALL_FEATURES").unwrap_or("false".to_string()) == "true";
 
     let pg_version = format!("pg{}", pg_sys::get_pg_major_version_string());
@@ -250,11 +252,21 @@ fn install_extension() -> eyre::Result<()> {
     command
         .arg("pgx")
         .arg("install")
+        .arg("--test")
         .arg("--pg-config")
         .arg(pg_config.path().ok_or(eyre!("No pg_config found"))?)
         .stdout(Stdio::inherit())
         .stderr(Stdio::inherit())
         .env("CARGO_TARGET_DIR", get_target_dir()?);
+    
+    if let Ok(manifest_path) = std::env::var("PGX_MANIFEST_PATH") {
+        command.arg("--manifest-path");
+        command.arg(manifest_path);
+    }
+
+    if let Ok(rust_log) = std::env::var("RUST_LOG") {
+        command.env("RUST_LOG", rust_log);
+    }
 
     if !features.trim().is_empty() {
         command.arg("--features");
@@ -268,7 +280,7 @@ fn install_extension() -> eyre::Result<()> {
     if all_features {
         command.arg("--all-features");
     }
-    
+
     if is_release {
         command.arg("--release");
     }
