@@ -4,11 +4,8 @@
 use pgx::*;
 
 #[pg_extern(immutable)]
-fn returns_tuple_with_attributes() -> (
-    name!(arg, String),
-    name!(arg2, String),
-) {
-   ("hi".to_string(), "bye".to_string())
+fn returns_tuple_with_attributes() -> (name!(arg, String), name!(arg2, String)) {
+    ("hi".to_string(), "bye".to_string())
 }
 
 #[cfg(any(test, feature = "pg_test"))]
@@ -31,7 +28,6 @@ mod tests {
         assert!(result)
     }
 
-    
     // Ensures `@FUNCTION_NAME@` is handled.
     #[pg_extern(sql = r#"
         CREATE OR REPLACE FUNCTION tests."overridden_sql_with_fn_name"() RETURNS void
@@ -45,10 +41,8 @@ mod tests {
 
     #[pg_test]
     fn test_overridden_sql_with_fn_name() {
-        let result = Spi::get_one::<bool>(
-            r#"SELECT tests."overridden_sql_with_fn_name"()"#,
-        )
-        .expect("failed to get SPI result");
+        let result = Spi::get_one::<bool>(r#"SELECT tests."overridden_sql_with_fn_name"()"#)
+            .expect("failed to get SPI result");
         assert!(result)
     }
 }
